/** \file  main_pi_openMp.c
 *  \brief Monte Carlo estimate of PI using openMP
 */
#include <omp.h>
#include <stdio.h>
#include <stdlib.h>


int main(int args, char *argv[]){

  int i,globCtr,nSamples,nThreads,localCtr,t,tid;
  unsigned short xi[3];
  double x,y;
  
  globCtr=0;
  nSamples=atoi(argv[1]);
  nThreads=atoi(argv[2]);

  #pragma omp parallel private(i,xi,x,y,localCtr,t,tid)
  {
    localCtr=0;
    xi[0] = 1;
    xi[1] = 3;
    xi[2] = tid = omp_get_thread_num();
    t = omp_get_num_threads(); 
  
    for(i=tid; i<nSamples; i+=t){
      x=erand48(xi);
      y=erand48(xi);
      if(x*x+y*y <= 1.0){
        localCtr++;
      }
    }
  
    #pragma omp critical
    {
      globCtr += localCtr;
    }
  } 

  fprintf(stdout,"number of threads = %d\n",nThreads);
  fprintf(stdout,"number of trials = %d\n",nSamples);
  fprintf(stdout,"pi_estim = %7.5lf\n",4.0*globCtr/nSamples);
  return 0;
}




